@@ -2,11 +2,12 @@ package cmdconfig
 
 import (
 	"fmt"
-	filehelpers "github.com/turbot/go-kit/files"
-	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"log"
 	"os"
 
+	filehelpers "github.com/turbot/go-kit/files"
+	"github.com/turbot/steampipe/pkg/steampipeconfig"
+
 	"github.com/spf13/viper"
 	"github.com/turbot/go-kit/types"
 	"github.com/turbot/steampipe/pkg/constants"
@@ -25,8 +26,10 @@ func BootstrapViper(loader *steampipeconfig.WorkspaceProfileLoader) error {
 	// set defaults from defaultWorkspaceProfile
 	SetDefaultsFromConfig(loader.DefaultProfile.ConfigMap())
 
-	// set defaults from env vars
-	setDefaultsFromEnv()
+	// set defaults for install dir and mod location from env vars
+	// this needs to be done since the workspace profile definitions exist in the
+	// default install dir
+	setDirectoryDefaultsFromEnv()
 
 	// NOTE: if an explicit workspace profile was set, default the mod location and install dir _now_
 	// All other workspace profile values are defaults _after defaulting to the connection config options
@@ -81,11 +84,12 @@ func SetDefaultsFromConfig(configMap map[string]interface{}) {
 // for keys which do not have a corresponding command flag, we need a separate defaulting mechanism
 func setBaseDefaults() {
 	defaults := map[string]interface{}{
-		constants.ArgUpdateCheck:    true,
-		constants.ArgTelemetry:      constants.TelemetryInfo,
-		constants.ArgDatabasePort:   constants.DatabaseDefaultPort,
-		constants.ArgMaxCacheSizeMb: constants.DefaultMaxCacheSizeMb,
-		constants.ArgAutoComplete:   true,
+		constants.ArgUpdateCheck:          true,
+		constants.ArgTelemetry:            constants.TelemetryInfo,
+		constants.ArgDatabasePort:         constants.DatabaseDefaultPort,
+		constants.ArgMaxCacheSizeMb:       constants.DefaultMaxCacheSizeMb,
+		constants.ArgAutoComplete:         true,
+		constants.ArgDatabaseStartTimeout: constants.DBStartTimeout.Seconds(),
 	}
 
 	for k, v := range defaults {
@@ -99,27 +103,41 @@ type envMapping struct {
 	varType string
 }
 
+// set default values of INSTALL_DIR and ModLocation from env vars
+func setDirectoryDefaultsFromEnv() {
+	envMappings := map[string]envMapping{
+		constants.EnvInstallDir:     {constants.ArgInstallDir, "string"},
+		constants.EnvWorkspaceChDir: {constants.ArgModLocation, "string"},
+		constants.EnvModLocation:    {constants.ArgModLocation, "string"},
+	}
+
+	for k, v := range envMappings {
+		SetDefaultFromEnv(k, v.configVar, v.varType)
+	}
+}
+
 // set default values from env vars
-func setDefaultsFromEnv() {
+func SetDefaultsFromEnv() {
 	// NOTE: EnvWorkspaceProfile has already been set as a viper default as we have already loaded workspace profiles
 	// (EnvInstallDir has already been set at same time but we set it again to make sure it has the correct precedence)
 
 	// a map of known environment variables to map to viper keys
 	envMappings := map[string]envMapping{
-		constants.EnvInstallDir:        {constants.ArgInstallDir, "string"},
-		constants.EnvWorkspaceChDir:    {constants.ArgModLocation, "string"},
-		constants.EnvModLocation:       {constants.ArgModLocation, "string"},
-		constants.EnvIntrospection:     {constants.ArgIntrospection, "string"},
-		constants.EnvTelemetry:         {constants.ArgTelemetry, "string"},
-		constants.EnvUpdateCheck:       {constants.ArgUpdateCheck, "bool"},
-		constants.EnvCloudHost:         {constants.ArgCloudHost, "string"},
-		constants.EnvCloudToken:        {constants.ArgCloudToken, "string"},
-		constants.EnvSnapshotLocation:  {constants.ArgSnapshotLocation, "string"},
-		constants.EnvWorkspaceDatabase: {constants.ArgWorkspaceDatabase, "string"},
-		constants.EnvServicePassword:   {constants.ArgServicePassword, "string"},
-		constants.EnvCheckDisplayWidth: {constants.ArgCheckDisplayWidth, "int"},
-		constants.EnvMaxParallel:       {constants.ArgMaxParallel, "int"},
-		constants.EnvQueryTimeout:      {constants.ArgDatabaseQueryTimeout, "int"},
+		constants.EnvInstallDir:           {constants.ArgInstallDir, "string"},
+		constants.EnvWorkspaceChDir:       {constants.ArgModLocation, "string"},
+		constants.EnvModLocation:          {constants.ArgModLocation, "string"},
+		constants.EnvIntrospection:        {constants.ArgIntrospection, "string"},
+		constants.EnvTelemetry:            {constants.ArgTelemetry, "string"},
+		constants.EnvUpdateCheck:          {constants.ArgUpdateCheck, "bool"},
+		constants.EnvCloudHost:            {constants.ArgCloudHost, "string"},
+		constants.EnvCloudToken:           {constants.ArgCloudToken, "string"},
+		constants.EnvSnapshotLocation:     {constants.ArgSnapshotLocation, "string"},
+		constants.EnvWorkspaceDatabase:    {constants.ArgWorkspaceDatabase, "string"},
+		constants.EnvServicePassword:      {constants.ArgServicePassword, "string"},
+		constants.EnvCheckDisplayWidth:    {constants.ArgCheckDisplayWidth, "int"},
+		constants.EnvMaxParallel:          {constants.ArgMaxParallel, "int"},
+		constants.EnvQueryTimeout:         {constants.ArgDatabaseQueryTimeout, "int"},
+		constants.EnvDatabaseStartTimeout: {constants.ArgDatabaseStartTimeout, "int"},
 	}
 
 	for k, v := range envMappings {
