@@ -18,6 +18,7 @@ import (
 type ConnectionPluginData struct {
 	Name    string
 	Config  string
+	Type    string
 	Options *options.Connection
 	Schema  *sdkproto.Schema
 }
@@ -34,10 +35,11 @@ type ConnectionPlugin struct {
 	SupportedOperations *proto.SupportedOperations
 }
 
-func (p ConnectionPlugin) addConnection(name string, config string, connectionOptions *options.Connection) {
+func (p ConnectionPlugin) addConnection(name string, config string, connectionOptions *options.Connection, connectionType string) {
 	p.ConnectionMap[name] = &ConnectionPluginData{
 		Name:    name,
 		Config:  config,
+		Type:    connectionType,
 		Options: connectionOptions,
 	}
 }
@@ -109,8 +111,14 @@ func CreateConnectionPlugins(connectionsToCreate []*modconfig.Connection) (reque
 	}
 
 	// if there were any failures, display them
-	for plugin, failure := range getResponse.FailureMap {
-		res.AddWarning(fmt.Sprintf("failed to start plugin '%s': %s", plugin, failure))
+	for failedPlugin, failure := range getResponse.FailureMap {
+		res.AddWarning(fmt.Sprintf("failed to start plugin '%s': %s", failedPlugin, failure))
+		// figure out which connections are provided by any failed plugins
+		for _, c := range connectionsToCreate {
+			if c.Plugin == failedPlugin {
+				res.AddFailedConnection(c.Name, failure)
+			}
+		}
 	}
 
 	// now create or retrieve a connection plugin for each connection
@@ -166,14 +174,13 @@ func CreateConnectionPlugins(connectionsToCreate []*modconfig.Connection) (reque
 	return requestedConnectionPluginMap, res
 }
 
+// requestedConnectionPluginMap is a map of connection plugins, keyed by connection name
+// the connection names which are the keys of this map are the connections
+// which were _requested_ in the parent CreateConnectionPlugins call (i.e. not necessarily all connections)
+// NOTE: the connection plugins may provide  _more_ connections that those requested
+// - we need to populate the schema for _all_ of them
 func populateConnectionPluginSchemas(requestedConnectionPluginMap map[string]*ConnectionPlugin) error {
 
-	// requestedConnectionPluginMap is a map of connection plugins, keyed by connection name
-	// the connection names which are the keys of this map are the connections
-	// which were _requested_ in the parent CreateConnectionPlugins call (i.e. not necessarily all connections)
-	// NOTE: the connection plugins may provide  _more_ connections that those requested
-	// - we need to populate the schema for _all_ of them
-
 	// build a map keyed by _all_ connection names provided by the connection plugins
 	connectionPluginMap := fullConnectionPluginMap(requestedConnectionPluginMap)
 
@@ -185,11 +192,14 @@ func populateConnectionPluginSchemas(requestedConnectionPluginMap map[string]*Co
 	log.Printf("[TRACE] populateConnectionPluginSchemas")
 
 	for connectionName, connectionPlugin := range connectionPluginMap {
-		log.Printf("[TRACE] populateConnectionPluginSchemas: connectionName: %s", connectionName)
+		// if this is an aggregator we must fetch the schema
+		isAggregator := connectionPlugin.ConnectionMap[connectionName].Type == modconfig.ConnectionTypeAggregator
+		log.Printf("[TRACE] populateConnectionPluginSchemas: connectionName: %s: isAggregator: %v", connectionName, isAggregator)
 		// does this plugin  exist in the static schema map?
 		schema, ok := staticSchemas[connectionPlugin.PluginName]
-		if !ok {
-			log.Printf("[TRACE] schema does not exist in list of static schemas, fetching")
+
+		if isAggregator || !ok {
+			log.Printf("[TRACE] fetching schema for connection %s, isAggregator: %v, gotSchema: %v", connectionName, isAggregator, ok)
 			log.Printf("[TRACE] GetSchema %s", connectionName)
 
 			// if not, fetch the schema
@@ -218,45 +228,6 @@ func populateConnectionPluginSchemas(requestedConnectionPluginMap map[string]*Co
 		return error_helpers.CombineErrors(errors...)
 	}
 	return nil
-
-	// we will only need to fetch the schema once for each plugin (apart from plugins with dynamic schema)
-
-	// map of plugin schemas - add schema for each plugin with a static schema
-
-	//
-
-	// we first new to build a map of schemas for each plugin
-	//
-	////log.Printf("[TRACE] populateConnectionPluginSchemas for %d connections", len(connections))
-	//staticSchemaMap, dynamicSchemaMap, err := buildPluginSchemaMap(connectionNames, pluginMap)
-	//if err != nil {
-	//	return err
-	//}
-	//
-	//// now build a map of connection to schema mode
-	//schemaModeMap := buildSchemaModeMap(connectionPluginMap, pluginSchemaMap)
-	//
-	//// now build a ConnectionSchemaMap object for the connections we are updating
-	//// - we can use this to identify the minimal set of schemas we need to fetch
-	//connectionSchemaMap := NewConnectionSchemaMapForConnections(connections, schemaModeMap)
-	//
-	//// for every connection with unique schema, fetch the schema and then set in all connections which share this schema
-	//for _, c := range connectionSchemaMap.UniqueSchemas() {
-	//	connectionPlugin, ok := connectionPluginMap[c]
-	//	if !ok {
-	//		// we must have had issues loading this plugin
-	//		continue
-	//	}
-	//	// retrieve the plugin schema from the schema map
-	//	pluginName := connectionPlugin.PluginName
-	//	schema := pluginSchemaMap[pluginName]
-	//	// now set this schema for all connections which share it
-	//	for _, connectionUsingSchema := range connectionSchemaMap[c] {
-	//		connectionPluginMap[connectionUsingSchema].ConnectionMap[connectionUsingSchema].Schema = schema
-	//	}
-	//}
-	//log.Printf("[WARN] populateConnectionPluginSchemas 5")
-	//return nil
 }
 
 // given a map of connection names to the connectionPlugins which proivide them,
@@ -275,108 +246,11 @@ func fullConnectionPluginMap(sparseConnectionPluginMap map[string]*ConnectionPlu
 	return connectionNameMap
 }
 
-//func populateMultiConnectionPluginSchemas(connections []*modconfig.Connection, connectionPluginMap map[string]*ConnectionPlugin, multiConnectionPlugins map[string]*ConnectionPlugin) error {
-//
-//	// we will only need to fetch the schema once for each plugin (apart from plugins with dynamic schema)
-//	// we first new to build a map of schemas for each plugin
-//
-//	pluginSchemaMap, err := buildPluginSchemaMap(connectionPluginMap)
-//	if err != nil {
-//		return err
-//	}
-//
-//	// now build a map of connection to schema mode
-//	schemaModeMap := buildSchemaModeMap(connectionPluginMap, pluginSchemaMap)
-//
-//	// now build a ConnectionSchemaMap object for the connections we are updating
-//	// - we can use this to identify the minimal set of schemas we need to fetch
-//	connectionSchemaMap := NewConnectionSchemaMapForConnections(connections, schemaModeMap)
-//
-//	// for every connection with unique schema, fetch the schema and then set in all connections which share this schema
-//	for _, c := range connectionSchemaMap.UniqueSchemas() {
-//		connectionPlugin, ok := connectionPluginMap[c]
-//		if !ok {
-//			// we must have had issues loading this plugin
-//			continue
-//		}
-//		// retrieve the plugin schema from the schema map
-//		pluginName := connectionPlugin.PluginName
-//		schema := pluginSchemaMap[pluginName]
-//		// now set this schema for all connections which share it
-//		for _, connectionUsingSchema := range connectionSchemaMap[c] {
-//			connectionPluginMap[connectionUsingSchema].Schema = schema
-//		}
-//	}
-//	return nil
-//}
-
-// build a map of plugin schemas, keyed by plugin name
-// NOTE: if a plugin has dynamic schema, we will later need to fetch the schema for _all_ connections
-//func buildPluginSchemaMap(pluginMap *connectionPluginMap) (error) {
-//	var errors []error
-//
-//	// build map of the static schemas, keyed by plugin
-//	staticSchemas := make(map[string]*sdkproto.Schema)
-//
-//	for connectionName, connectionPlugin := range pluginMap.connectionNameMap {
-//		// does this plugin  exist in the static schema map?
-//		schema, ok := staticSchemas[connectionPlugin.PluginName]
-//		if !ok {
-//			// if not, fetch the schema
-//			var err error
-//			schema, err = connectionPlugin.PluginClient.GetSchema(connectionName)
-//			if err != nil {
-//				log.Printf("[TRACE] failed to get schema for connection '%s': %s", connectionName, err)
-//				errors = append(errors, err)
-//				continue
-//			}
-//
-//			// if the schema is static, add to static schema map
-//			if schema.Mode == sdkplugin.SchemaModeStatic {
-//				staticSchemas[connectionPlugin.PluginName] = schema
-//			}
-//		}
-//
-//		// set the schema on the connection plugin
-//		connectionPlugin.ConnectionMap[connectionName].Schema = schema
-//
-//	}
-//	if len(errors) > 0 {
-//		return utils.CombineErrors(errors...)
-//	}
-//	return nil
-//}
-//
-//func buildPluginMaps(connectionPluginMap map[string]*ConnectionPlugin) (pluginConnectionMap map[string][]string, pluginNameMap map[string]*ConnectionPlugin) {
-//	pluginConnectionMap = make(map[string][]string)
-//	pluginNameMap = make(map[string]*ConnectionPlugin)
-//	for _, connectionPlugin := range connectionPluginMap {
-//		connectionNames := connectionPlugin.GetConnectionNames()
-//		pluginConnectionMap[connectionPlugin.PluginName] = append(pluginConnectionMap[connectionPlugin.PluginName], connectionNames...)
-//		if _, ok := pluginNameMap[connectionPlugin.PluginName]; !ok {
-//			pluginNameMap[connectionPlugin.PluginName] = connectionPlugin
-//		}
-//	}
-//	return
-//}
-//
-//func buildSchemaModeMap(connectionPluginMap map[string]*ConnectionPlugin, pluginSchemaMap map[string]*sdkproto.Schema) map[string]string {
-//	schemaModeMap := make(map[string]string, len(connectionPluginMap))
-//
-//	for connectionName, connectionPlugin := range connectionPluginMap {
-//		schema := pluginSchemaMap[connectionPlugin.PluginName]
-//		schemaModeMap[connectionName] = schema.Mode
-//	}
-//	return schemaModeMap
-//}
-
+// createConnectionPlugin sttaches to the plugin process
 func createConnectionPlugin(connection *modconfig.Connection, reattach *proto.ReattachConfig) (*ConnectionPlugin, error) {
-
 	log.Printf("[TRACE] createConnectionPlugin for connection %s", connection.Name)
 	pluginName := connection.Plugin
 	connectionName := connection.Name
-	connectionConfig := connection.Config
-	connectionOptions := connection.Options
 
 	log.Printf("[TRACE] plugin manager returned reattach config for connection '%s' - pid %d",
 		connectionName, reattach.Pid)
@@ -401,7 +275,7 @@ func createConnectionPlugin(connection *modconfig.Connection, reattach *proto.Re
 	// if multiple connections are NOT supported, add the config for our one and only connection
 	if reattach.SupportedOperations == nil || !reattach.SupportedOperations.MultipleConnections {
 		log.Printf("[TRACE] multiple connections NOT supported - adding single connection '%s' to ConnectionPlugin", connectionName)
-		connectionPlugin.addConnection(connectionName, connectionConfig, connectionOptions)
+		connectionPlugin.addConnection(connectionName, connection.Config, connection.Options, connection.Type)
 	} else {
 		log.Printf("[TRACE] multiple connections ARE supported - adding all connections to ConnectionPlugin: %v", reattach.Connections)
 		// now identify all connections serviced by this plugin
@@ -414,7 +288,7 @@ func createConnectionPlugin(connection *modconfig.Connection, reattach *proto.Re
 			if !ok {
 				return nil, fmt.Errorf("no connection config loaded for '%s'", c)
 			}
-			connectionPlugin.addConnection(c, config.Config, config.Options)
+			connectionPlugin.addConnection(c, config.Config, config.Options, config.Type)
 		}
 	}
 
