@@ -36,7 +36,7 @@ func resolveChildrenFromNames(childNames []string, block *hcl.Block, supportedCh
 			break
 		}
 
-		resource, found := modconfig.GetResource(mod, parsedName)
+		resource, found := mod.GetResource(parsedName)
 		// ensure this item is a mod tree item
 		child, ok := resource.(modconfig.ModTreeItem)
 		if !found || !ok {
