@@ -16,6 +16,7 @@ export BATS_PATH=$MY_PATH/lib/bats/bin/bats
 export LIB_BATS_ASSERT=$MY_PATH/lib/bats-assert
 export LIB_BATS_SUPPORT=$MY_PATH/lib/bats-support
 export TEST_DATA_DIR=$MY_PATH/test_data/templates
+export SNAPSHOTS_DIR=$MY_PATH/test_data/snapshots
 export SRC_DATA_DIR=$MY_PATH/test_data/source_files
 export WORKSPACE_DIR=$MY_PATH/test_data/sample_workspace
 export BAD_TEST_MOD_DIR=$MY_PATH/test_data/failure_test_mod
@@ -30,8 +31,12 @@ export STEAMPIPE_CONNECTION_WATCHER=false
 export STEAMPIPE_INTROSPECTION=info
 export DEFAULT_WORKSPACE_PROFILE_LOCATION=$MY_PATH/test_data/source_files/workspace_profile_default
 
+# from GH action env variables
+export SPIPETOOLS_PG_CONN_STRING=$SPIPETOOLS_PG_CONN_STRING
+export SPIPETOOLS_TOKEN=$SPIPETOOLS_TOKEN
+
 # Must have these commands for the test suite to run
-declare -a required_commands=("jq" "sed" "steampipe" "rm" "mv" "cp" "mkdir" "cd" "head" "wc" "find" "basename" "dirname" "touch")
+declare -a required_commands=("jq" "sed" "steampipe" "rm" "mv" "cp" "mkdir" "cd" "head" "wc" "find" "basename" "dirname" "touch" "jd")
 
 for required_command in "${required_commands[@]}"
 do
