@@ -3,14 +3,13 @@ import useDeepCompareEffect from "use-deep-compare-effect";
 import useTemplateRender from "../../../../hooks/useTemplateRender";
 import {
   Category,
-  CategoryFields,
+  CategoryProperties,
   KeyValuePairs,
   RowRenderResult,
 } from "../../common/types";
 import { classNames } from "../../../../utils/styles";
 import { DashboardDataModeLive } from "../../../../types";
 import { ErrorIcon } from "../../../../constants/icons";
-import { isRelativeUrl } from "../../../../utils/url";
 import { useDashboard } from "../../../../hooks/useDashboard";
 import { useEffect, useState } from "react";
 
@@ -20,7 +19,7 @@ type RowPropertiesTitleProps = {
 };
 
 type RowPropertiesProps = {
-  fields: CategoryFields | null;
+  propertySettings: CategoryProperties | null;
   properties: KeyValuePairs | null;
 };
 
@@ -53,7 +52,6 @@ const RowPropertyItemValue = ({
 }: RowPropertyItemProps) => {
   const {
     components: { ExternalLink },
-    dataMode,
   } = useDashboard();
   const [href, setHref] = useState<string | null>(null);
   const [error, setError] = useState<string | null>(null);
@@ -63,26 +61,20 @@ const RowPropertyItemValue = ({
       setError(null);
       return;
     }
-    const renderedTemplateForField = rowTemplateData[name];
-    if (!renderedTemplateForField) {
+    const renderedTemplateForProperty = rowTemplateData[name];
+    if (!renderedTemplateForProperty) {
       setHref(null);
       setError(null);
       return;
     }
-    if (renderedTemplateForField.result) {
-      // We only want to render the HREF if it's live, or it's snapshot and absolute
-      const isRelative = isRelativeUrl(renderedTemplateForField.result);
-      setHref(
-        dataMode !== DashboardDataModeLive && isRelative
-          ? null
-          : renderedTemplateForField.result
-      );
+    if (renderedTemplateForProperty.result) {
+      setHref(renderedTemplateForProperty.result);
       setError(null);
-    } else if (renderedTemplateForField.error) {
+    } else if (renderedTemplateForProperty.error) {
       setHref(null);
-      setError(renderedTemplateForField.error);
+      setError(renderedTemplateForProperty.error);
     }
-  }, [dataMode, name, rowTemplateData]);
+  }, [name, rowTemplateData]);
 
   const wrapClassName = wrap ? "whitespace-normal" : "truncate";
   const linkClassName = classNames("link-highlight", wrapClassName);
@@ -166,37 +158,37 @@ const RowPropertyItem = ({
         value={value}
       />
     </div>
-    // <div className="space-x-2">
-    //   <span>{name}</span>
-    //   <span>=</span>
-    //   <span>{value}</span>
-    // </div>
   );
 };
 
-const RowProperties = ({ properties = {}, fields }: RowPropertiesProps) => {
+const RowProperties = ({
+  properties = {},
+  propertySettings,
+}: RowPropertiesProps) => {
+  const { dataMode } = useDashboard();
   const [rowTemplateData, setRowTemplateData] =
     useState<RowRenderResult | null>(null);
   const { ready: templateRenderReady, renderTemplates } = useTemplateRender();
 
   useDeepCompareEffect(() => {
-    if (!templateRenderReady || isEmpty(fields) || !properties) {
+    // We only want to do the interpolated template rendering in live views
+    if (dataMode !== DashboardDataModeLive) {
+      setRowTemplateData(null);
+      return;
+    }
+
+    if (!templateRenderReady || isEmpty(propertySettings) || !properties) {
       setRowTemplateData(null);
       return;
     }
 
     const doRender = async () => {
       const templates = {};
-      for (const [name, field] of Object.entries(fields || {})) {
-        if (field.display !== "none" && field.href) {
-          templates[name] = field.href;
+      for (const [name, property] of Object.entries(propertySettings || {})) {
+        if (property.display !== "none" && property.href) {
+          templates[name] = property.href;
         }
       }
-      // const templates = Object.fromEntries(
-      //   fields
-      //     .filter((col) => col.display !== "none" && !!col.href_template)
-      //     .map((col) => [col.name, col.href_template as string])
-      // );
       if (isEmpty(templates) || !properties) {
         setRowTemplateData(null);
         return;
@@ -206,13 +198,19 @@ const RowProperties = ({ properties = {}, fields }: RowPropertiesProps) => {
     };
 
     doRender();
-  }, [fields, properties, renderTemplates, templateRenderReady]);
+  }, [
+    dataMode,
+    properties,
+    propertySettings,
+    renderTemplates,
+    templateRenderReady,
+  ]);
 
   return (
     <div className="space-y-2">
       {Object.entries(properties || {}).map(([key, value]) => {
-        const fieldDefinition = fields?.[key];
-        if (fieldDefinition && fieldDefinition.display === "none") {
+        const propertyDefinition = propertySettings?.[key];
+        if (propertyDefinition && propertyDefinition.display === "none") {
           return null;
         }
         return (
@@ -221,7 +219,9 @@ const RowProperties = ({ properties = {}, fields }: RowPropertiesProps) => {
             name={key}
             value={value}
             rowTemplateData={rowTemplateData}
-            wrap={fieldDefinition ? fieldDefinition.wrap === "all" : false}
+            wrap={
+              propertyDefinition ? propertyDefinition.wrap === "all" : false
+            }
           />
         );
       })}
